@@ -17,5 +17,6 @@ connectConfig = ConnectConfig(
 	AMQP_URL=AMQP_URL,
 	ORCHESTRATOR_QUEUE=ORCHESTRATOR_QUEUE,
 	HOST_HEARTBEAT_QUEUE=HOST_HEARTBEAT_QUEUE,
-	HOST_QUEUE=HOST_PYTHON_QUEUE
+	HOST_QUEUE=HOST_PYTHON_QUEUE,
+	concurrency_TasksNo=2,
 )
